bayespy.inference.vmp.transformations.RotateVaryingMarkovChain.__init__
=======================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateVaryingMarkovChain.__init__